#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import TYPE_CHECKING

from pycatia.dmaps_interfaces.items import Items
from pycatia.dmaps_interfaces.outputs import Outputs
from pycatia.knowledge_interfaces.parameters import Parameters
from pycatia.knowledge_interfaces.relations import Relations
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.types.general import cat_variant

if TYPE_CHECKING:
    from pycatia.dmaps_interfaces.activities import Activities
    from pycatia.dmaps_interfaces.resources import Resources


class Activity(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Activity
                | 
                | The object that represents an activity.
                | 
                | It groups the most important methods related to an activity and enables to get
                | the management interfaces (hierarchy management, control flow management, *
                | ...).
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.activity = com_object

    @property
    def attr_count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttrCount() As long (Read Only)
                | 
                |     This property returns the number of attributes of the current
                |     activity.
                | 
                |     Returns:
                |         oNbAttr The number of attributes

        :rtype: int
        """

        return self.activity.AttrCount

    @property
    def beginning_date(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property BeginningDate() As double
                | 
                |     This property returns the beginning date of the current
                |     activity.
                | 
                |     Returns:
                |         oBegin The beginning date of the current activity

        :rtype: float
        """

        return self.activity.BeginningDate

    @beginning_date.setter
    def beginning_date(self, value: float):
        """
        :param float value:
        """

        self.activity.BeginningDate = value

    @property
    def calculated_begin_time(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CalculatedBeginTime() As double (Read Only)
                | 
                |     This property returns and calculated time cyle on the current
                |     activity.
                | 
                |     Returns:
                |         oCBT The calculated begin time of the current activity

        :rtype: float
        """

        return self.activity.CalculatedBeginTime

    @property
    def calculated_cycle_time(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CalculatedCycleTime() As double (Read Only)
                | 
                |     This property returns and sets the calculated time cyle on the current
                |     activity.
                | 
                |     Returns:
                |         oCCT The calculated time cycle of the current activity

        :rtype: float
        """

        return self.activity.CalculatedCycleTime

    @property
    def children_activities(self) -> 'Activities':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ChildrenActivities() As Activities (Read Only)
                | 
                |     This property returns the interface which manages the children hierarchy on
                |     the activity. Please note that it used to return all children, but from R20SP4
                |     it returns only exposed children, which could be different from all children.

        :rtype: Activities
        """

        from pycatia.dmaps_interfaces.activities import Activities
        return Activities(self.activity.ChildrenActivities)

    @property
    def cycle_time(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CycleTime() As double
                | 
                |     This property returns and set the time cyle on the current
                |     activity.
                | 
                |     Returns:
                |         oCT The time cycle of the current activity 
                |     Parameters:
                | 
                |         iCT
                |             The specified time cycle of the current activity

        :rtype: float
        """

        return self.activity.CycleTime

    @cycle_time.setter
    def cycle_time(self, value: float):
        """
        :param float value:
        """

        self.activity.CycleTime = value

    @property
    def description(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Description() As CATBSTR
                | 
                |     This property returns and set the description on the current
                |     activity.
                | 
                |     Returns:
                |         oDescriptionBSTR The description of the current activity
                |         
                |     Parameters:
                | 
                |         iDescriptionBSTR
                |             The specified description of the current activity

        :rtype: str
        """

        return self.activity.Description

    @description.setter
    def description(self, value: str):
        """
        :param str value:
        """

        self.activity.Description = value

    @property
    def end_date(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property EndDate() As double (Read Only)
                | 
                |     This property returns the end date of the current
                |     activity.
                | 
                |     Returns:
                |         oEnd The end date of the current activity. Till V5R13, this method is
                |         returning S_OK even if there is no good implementation. Starting from V5R14
                |         this method will return E_NOIMPL. Hence all the scripts that use this method
                |         would have to be updated to accomodate this change.

        :rtype: float
        """

        return self.activity.EndDate

    @property
    def items(self) -> Items:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Items() As Items (Read Only)
                | 
                |     This property returns the interface which manages the items or input
                |     products/components assigned to the current activity

        :rtype: Items
        """

        return Items(self.activity.Items)

    @property
    def next_cf_activities(self) -> 'Activities':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NextCFActivities() As Activities (Read Only)
                | 
                |     This property returns the interface which manages the downstream control
                |     flow hierarchy on the activity.

        :rtype: Activities
        """

        from pycatia.dmaps_interfaces.activities import Activities
        return Activities(self.activity.NextCFActivities)

    @property
    def next_prf_activities(self) -> 'Activities':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NextPRFActivities() As Activities (Read Only)
                | 
                |     This property returns the interface which manages the downstream product
                |     flow hierarchy on the activity.

        :rtype: Activities
        """

        from pycatia.dmaps_interfaces.activities import Activities
        return Activities(self.activity.NextPRFActivities)

    @property
    def outputs(self) -> Outputs:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Outputs() As Outputs (Read Only)
                | 
                |     This property returns the interface which manages the output
                |     products/components of the current activity

        :rtype: Outputs
        """

        return Outputs(self.activity.Outputs)

    @property
    def parameters(self) -> Parameters:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Parameters() As Parameters (Read Only)
                | 
                |     This property returns the interface which manages the knowlegde parameters
                |     of the activity.

        :rtype: Parameters
        """

        return Parameters(self.activity.Parameters)

    @property
    def possible_precedence_activities(self) -> 'Activities':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PossiblePrecedenceActivities() As Activities (Read
                | Only)
                | 
                |     This property returns list of Possible Precedence Activities defined on
                |     Current Activity.
                | 
                |     Parameters:
                | 
                |         oActivities
                |             List of Activities that must precede the Current
                |             Activity

        :rtype: Activities
        """

        from pycatia.dmaps_interfaces.activities import Activities
        return Activities(self.activity.PossiblePrecedenceActivities)

    @property
    def precedence_activities(self) -> 'Activities':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PrecedenceActivities() As Activities (Read Only)
                | 
                |     This property returns list of Precedence Activities defined on Current
                |     Activity.
                | 
                |     Parameters:
                | 
                |         oActivities
                |             List of Activities that must precede the Current
                |             Activity

        :rtype: Activities
        """

        from pycatia.dmaps_interfaces.activities import Activities
        return Activities(self.activity.PrecedenceActivities)

    @property
    def previous_cf_activities(self) -> 'Activities':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PreviousCFActivities() As Activities (Read Only)
                | 
                |     This property returns the interface which manages the upstream control flow
                |     hierarchy on the activity.

        :rtype: Activities
        """

        from pycatia.dmaps_interfaces.activities import Activities
        return Activities(self.activity.PreviousCFActivities)

    @property
    def previous_prf_activities(self) -> 'Activities':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PreviousPRFActivities() As Activities (Read Only)
                | 
                |     This property returns the interface which manages the upstream product flow
                |     hierarchy on the activity.

        :rtype: Activities
        """

        from pycatia.dmaps_interfaces.activities import Activities
        return Activities(self.activity.PreviousPRFActivities)

    @property
    def process_id(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ProcessID() As CATBSTR (Read Only)
                | 
                |     This property returns process identifier on the current
                |     activity.
                | 
                |     Parameters:
                | 
                |         oProcessID
                |             The process ID of the current activity

        :rtype: str
        """

        return self.activity.ProcessID

    @property
    def relations(self) -> Relations:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Relations() As Relations (Read Only)
                | 
                |     This property returns the interface which manages the knowlegde relations
                |     of the activity.

        :rtype: Relations
        """

        return Relations(self.activity.Relations)

    @property
    def resources(self) -> 'Resources':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Resources() As Resources (Read Only)
                | 
                |     This property returns the interface which manages the resources hierarchy
                |     on the activity.

        :rtype: Resources
        """

        from pycatia.dmaps_interfaces.resources import Resources
        return Resources(self.activity.Resources)

    @property
    def type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Type() As CATBSTR (Read Only)
                | 
                |     This method returns the type of the current activity.
                | 
                |     Parameters:
                | 
                |         oType
                |             The type of the current activity

        :rtype: str
        """

        return self.activity.Type

    def add_activity_constraint(
            self,
            i_activity: 'Activity',
            i_constraint_type: str
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddActivityConstraint(Activity iActivity,
                | SPPProcessConstraintType iConstraintType)
                | 
                |     Create a constraint between current activity and input
                |     activity
                | 
                |     Parameters:
                | 
                |         iActivity
                |             Activity with which the constraint to be created. 
                |         iConstraintType
                |             Type of the Constraint. It may be one of the following:
                |             Precedence_Constraint, Start_Constraint, End_Constraint,
                |             
                | 
                |     Returns:
                |     S_OKOn Success
                |     S_FALSEIf a constraint already exists.
                |     E_FAILIf the constraint is NOT created.

        :param Activity i_activity:
        :param str i_constraint_type:
        :rtype: None
        """
        return self.activity.AddActivityConstraint(i_activity.com_object, i_constraint_type)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_activity_constraint'
        # # vba_code = """
        # # Public Function add_activity_constraint(activity)
        # #     Dim iActivity (2)
        # #     activity.AddActivityConstraint iActivity
        # #     add_activity_constraint = iActivity
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_attr(self, i_attribute_name: str, attr_type: str, i_attribute_prompt_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddAttr(CATBSTR iAttributeName,
                | SPPProcessAttributeType AttrType,
                | CATBSTR iAttributePromptName)
                | 
                |     Adds attribute to an Activity.
                | 
                |     Parameters:
                | 
                |         iAttributeName
                |             Name of the attribute to add 
                |         AttrType
                |             Type of the attribute to add. It may be one of the following:
                |             Integer_Attribute or 0 for integer, Double_Attribute or 1 for double, or
                |             String_Attribute or 2 for string 
                |         iAttributePromptName
                |             Prompt Name of the attribute to add

        :param str i_attribute_name:
        :param str attr_type:
        :param str i_attribute_prompt_name:
        :rtype: None
        """
        return self.activity.AddAttr(i_attribute_name, attr_type, i_attribute_prompt_name)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_attr'
        # # vba_code = """
        # # Public Function add_attr(activity)
        # #     Dim iAttributeName (2)
        # #     activity.AddAttr iAttributeName
        # #     add_attr = iAttributeName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def attr_name(self, i_index: int) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AttrName(long iIndex) As CATBSTR
                | 
                |     This method returns the name for the specified attribute.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The attribute index 
                |         oName
                |             The attribute name

        :param int i_index:
        :rtype: str
        """
        return self.activity.AttrName(i_index)

    def attr_value(self, i_index: cat_variant) -> cat_variant:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AttrValue(CATVariant iIndex) As CATVariant
                | 
                |     This method returns the value for the specified attribute.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The attribute identifier 
                | 
                |     Returns:
                |         oAttVal The attribute value

        :param cat_variant i_index:
        :rtype: cat_variant
        """
        return self.activity.AttrValue(i_index)

    def create_child(self, i_type_of_child: str) -> 'Activity':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateChild(CATBSTR iTypeOfChild) As Activity
                | 
                |     This method creates a new child activity of the requested
                |     type.
                | 
                |     Parameters:
                | 
                |         iTypeOfChild
                |             The type of the child activity to create. 
                |         oCreatedChild
                |             The new created child activity.

        :param str i_type_of_child:
        :rtype: Activity
        """
        return Activity(self.activity.CreateChild(i_type_of_child))

    def create_link(self, i_second_activity: 'Activity') -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateLink(Activity iSecondActivity)
                | 
                |     This method creates a link from the current activity to another
                |     activity.
                | 
                |     Parameters:
                | 
                |         iSecondActivity
                |             The activity that will be linked to the current
                |             activity.

        :param Activity i_second_activity:
        :rtype: None
        """
        return self.activity.CreateLink(i_second_activity.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_link'
        # # vba_code = """
        # # Public Function create_link(activity)
        # #     Dim iSecondActivity (2)
        # #     activity.CreateLink iSecondActivity
        # #     create_link = iSecondActivity
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_activity_constraints(self, i_constraint_type: str, o_constrt_list: 'Activities') -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetActivityConstraints(SPPProcessConstraintType
                | iConstraintType,
                | Activities oConstrtList)
                | 
                |     Get List of constraint activities that exists on the current
                |     Activity
                | 
                |     Parameters:
                | 
                |         iConstraintType
                |             Type of the Constraints to be returned. It may be one of the
                |             following: Precedence_Constraint, Start_Constraint, End_Constraint,
                |             All_Constraints 
                | 
                |     Returns:
                |         oConstrtList ( Allocate the memory.If not, it allocates internally and
                |         you need to clean it after usage) 
                |     List of Activities with which the current activity has
                |     constraints
                |     Returns:
                |         oConstraintTypeList (It is an optional output used only if user
                |         interested) ( Allocate the memory.If not, it allocates internally and you need
                |         to clean it after usage) 
                |     List of constraint types for each actvity that exists in
                |     oConstrtList
                |     Current activity has a constraint with first activity in oConstrtList and
                |     its constraint type is mentioned in first field of
                |     oConstraintTypeList

        :param str i_constraint_type:
        :param Activities o_constrt_list:
        :rtype: None
        """
        return self.activity.GetActivityConstraints(i_constraint_type, o_constrt_list.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_activity_constraints'
        # # vba_code = """
        # # Public Function get_activity_constraints(activity)
        # #     Dim iConstraintType (2)
        # #     activity.GetActivityConstraints iConstraintType
        # #     get_activity_constraints = iConstraintType
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_technological_object(self, i_application_type: str) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTechnologicalObject(CATBSTR iApplicationType) As
                | CATBaseDispatch
                | 
                |     Returns the process's applicative data which type is the given parameter.
                |     The data returned can be either a collection or a simple
                |     object.
                | 
                |     Parameters:
                | 
                |         iApplicationType
                |             The type of applicative data searched. 
                | 
                |     Example:
                | 
                |           This example retrieves the GraphEditor position for
                |           the
                |          Loading1 activity.
                |          
                | 
                |          Dim GEPosition 
                |          Set GEPosition = Loading1.GetTechnologicalObject("GEPosition")

        :param str i_application_type:
        :rtype: AnyObject
        """
        return self.activity.GetTechnologicalObject(i_application_type)

    def is_sub_type_of(self, i_name: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsSubTypeOf(CATBSTR iName) As boolean
                | 
                |     This method allows to test the type of a specific
                |     activity.
                | 
                |     Parameters:
                | 
                |         iName
                |             The name of the type to test 
                | 
                |     Returns:
                |         oVal The logical value returned by the test

        :param str i_name:
        :rtype: bool
        """
        return self.activity.IsSubTypeOf(i_name)

    def remove_activity_constraint(self, i_activity: 'Activity', i_constraint_type: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveActivityConstraint(Activity iActivity,
                | SPPProcessConstraintType iConstraintType)
                | 
                |     Remove a constraint between current activity and input
                |     activity
                | 
                |     Parameters:
                | 
                |         iActivity
                |             Activity with which the constraint to be removed. 
                |         iConstraintType
                |             Type of the Constraint to be removed. It may be one of the
                |             following: Precedence_Constraint, Start_Constraint, End_Constraint,
                |             All_Constraints 
                | 
                |     Returns:
                |     S_OKOn Success
                |     S_FALSEIf a constraint does not exists.
                |     E_FAILIf the constraint can not be removed or the Function fails because
                |     of any reason.

        :param Activity i_activity:
        :param str i_constraint_type:
        :rtype: None
        """
        return self.activity.RemoveActivityConstraint(i_activity.com_object, i_constraint_type)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_activity_constraint'
        # # vba_code = """
        # # Public Function remove_activity_constraint(activity)
        # #     Dim iActivity (2)
        # #     activity.RemoveActivityConstraint iActivity
        # #     remove_activity_constraint = iActivity
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_attr(self, i_attribute_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveAttr(CATBSTR iAttributeName)
                | 
                |     Removes attributes to an Activity type.
                | 
                |     Parameters:
                | 
                |         iAttributeName
                |             Name of the attribute to remove

        :param str i_attribute_name:
        :rtype: None
        """
        return self.activity.RemoveAttr(i_attribute_name)

    def remove_link(self, i_second_activity: 'Activity') -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveLink(Activity iSecondActivity)
                | 
                |     This method removes a link existing on the current
                |     activity.
                | 
                |     Parameters:
                | 
                |         iSecondActivity
                |             The activity on which the link will be removed.

        :param Activity i_second_activity:
        :rtype: None
        """
        return self.activity.RemoveLink(i_second_activity.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_link'
        # # vba_code = """
        # # Public Function remove_link(activity)
        # #     Dim iSecondActivity (2)
        # #     activity.RemoveLink iSecondActivity
        # #     remove_link = iSecondActivity
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_process_id(self, i_process_id: str, i_check_unique: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetProcessID(CATBSTR iProcessID,
                | boolean iCheckUnique)
                | 
                |     Sets the process ID of the current activity
                | 
                |     Parameters:
                | 
                |         iProcessID
                |             Input Process ID string 
                |         iCheckUnique
                |             Option to enable uniqueness check

        :param str i_process_id:
        :param bool i_check_unique:
        :rtype: None
        """
        return self.activity.SetProcessID(i_process_id, i_check_unique)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_process_id'
        # # vba_code = """
        # # Public Function set_process_id(activity)
        # #     Dim iProcessID (2)
        # #     activity.SetProcessID iProcessID
        # #     set_process_id = iProcessID
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Activity(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class ManufacturingToolCorrector(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ManufacturingToolCorrector
                | 
                | Manufacturing tool corrector.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_tool_corrector = com_object

    @property
    def diameter(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Diameter() As double (Read Only)
                | 
                |     Gives the corrector diameter tool diameter.
                |     Returns HRESULT.

        :rtype: float
        """

        return self.manufacturing_tool_corrector.Diameter

    @property
    def length_number(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property LengthNumber() As short (Read Only)
                | 
                |     Gives the corrector length number.
                |     Returns HRESULT.

        :rtype: int
        """

        return self.manufacturing_tool_corrector.LengthNumber

    @property
    def number(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Number() As short (Read Only)
                | 
                |     Gives the corrector number.
                |     Returns HRESULT.

        :rtype: int
        """

        return self.manufacturing_tool_corrector.Number

    @property
    def point(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Point() As CATBSTR (Read Only)
                | 
                |     Gives the corrector type point.
                |     oPoint : Type point (Ex: P1, ..., P9)
                |     Returns HRESULT.

        :rtype: str
        """

        return self.manufacturing_tool_corrector.Point

    @property
    def radius_number(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RadiusNumber() As short (Read Only)
                | 
                |     Gives the corrector radius number.
                |     Returns HRESULT.

        :rtype: int
        """

        return self.manufacturing_tool_corrector.RadiusNumber

    def get_values(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetValues(CATBSTR oPoint,
                | short oNumber,
                | short oLengthNumber,
                | short oRadiusNumber,
                | double oDiameter)
                | 
                |     Gives the corrector values.
                |     oPoint : Type point (Ex: P1, ..., P9)
                |     oNumber : Corrector Number
                |     oLengthNumber : Corrector Length Number
                |     oRadiusNumber : Corrector Radius Number
                |     oDiameter : Tool Diameter where corrector applyes (if non fixed corrector)
                |     Returns HRESULT.

        :rtype: tuple
        """
        return self.manufacturing_tool_corrector.GetValues()

    def set_values(
            self,
            o_point: str,
            o_number: int,
            o_length_number: int,
            o_radius_number: int,
            o_diameter: float
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetValues(CATBSTR oPoint,
                | short oNumber,
                | short oLengthNumber,
                | short oRadiusNumber,
                | double oDiameter)
                | 
                |     Defines the corrector values.
                |     iPoint : Type point (Ex: P1, ..., P9)
                |     iNumber : Corrector Number
                |     iLengthNumber : Corrector Length Number
                |     iRadiusNumber : Corrector Radius Number
                |     iDiameter : Tool Diameter where corrector applyes (if non fixed corrector)
                |     Returns HRESULT.

        :param str o_point:
        :param int o_number:
        :param int o_length_number:
        :param int o_radius_number:
        :param float o_diameter:
        :rtype: None
        """
        return self.manufacturing_tool_corrector.SetValues(
            o_point,
            o_number,
            o_length_number,
            o_radius_number,
            o_diameter
        )

    def __repr__(self):
        return f'ManufacturingToolCorrector(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_human_sim_interfaces.worker_activity import WorkerActivity


class WalkActivity(WorkerActivity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                         DNBHumanSimInterfaces.WorkerActivity
                |                             WalkActivity

    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.walk_activity = com_object

    @property
    def body_pose(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property BodyPose() As HTSBodyPoseOptions
                | 
                |     Returns or Sets Body Posture option (see HTSBodyPoseOptions for list of
                |     possible values)

        :return: enum hts_body_pose_options
        :rtype: int
        """

        return self.walk_activity.BodyPose

    @body_pose.setter
    def body_pose(self, value: int):
        """
        :param int value: enum hts_body_pose_options
        """

        self.walk_activity.BodyPose = value

    @property
    def motion_basis(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MotionBasis() As HTSWalkMotionBasis
                | 
                |     Returns or Sets Motion-Basis (see HTSWalkMotionBasis for list of possible
                |     values)

        :return: enum hts_walk_motion_basis
        :rtype: int
        """

        return self.walk_activity.MotionBasis

    @motion_basis.setter
    def motion_basis(self, value: int):
        """
        :param int value: enum hts_walk_motion_basis
        """

        self.walk_activity.MotionBasis = value

    @property
    def stride(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Stride() As HTSStrideOptions
                | 
                |     Returns or Sets Stride option (see HTSStrideOptions for list of possible
                |     values)

        :return: enum hts_stride_options
        :rtype: int
        """

        return self.walk_activity.Stride

    @stride.setter
    def stride(self, value: int):
        """
        :param int value: enum hts_stride_options
        """

        self.walk_activity.Stride = value

    @property
    def swing(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Swing() As HTSSwingOptions
                | 
                |     Returns or Sets Swing option (see HTSSwingOptions for list of possible
                |     values)

        :return: enum hts_swing_options
        :rtype: int
        """

        return self.walk_activity.Swing

    @swing.setter
    def swing(self, value: int):
        """
        :param int value: enum hts_swing_options
        """

        self.walk_activity.Swing = value

    @property
    def user_speed(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UserSpeed() As double
                | 
                |     Returns or Sets Speed for Walk Activity

        :rtype: float
        """

        return self.walk_activity.UserSpeed

    @user_speed.setter
    def user_speed(self, value: float):
        """
        :param float value:
        """

        self.walk_activity.UserSpeed = value

    @property
    def user_time(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UserTime() As double
                | 
                |     Returns or Sets Time for Walk Activity

        :rtype: float
        """

        return self.walk_activity.UserTime

    @user_time.setter
    def user_time(self, value: float):
        """
        :param float value:
        """

        self.walk_activity.UserTime = value

    @property
    def walk_length(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property WalkLength() As double (Read Only)
                | 
                |     Returns WalkLength for Walk Activity

        :rtype: float
        """

        return self.walk_activity.WalkLength

    def get_walk_curve_def_points(self, i_num_points: int, ad_points: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetWalkCurveDefPoints(long iNumPoints,
                | CATSafeArrayVariant adPoints)
                | 
                |     This gets the Walk Path definition Point
                | 
                |     Parameters:
                | 
                |         iNumPoints
                |             Number of Coplanar-Points defining the Walk Path in Plane
                |             
                |         adPoints
                |             Point values x1,y1,z1 , x2,y2,z2, .... Area of Plane coordinates
                |             User needs to pass in sufficiently large-sized
                |             array

        :param int i_num_points:
        :param tuple ad_points:
        :rtype: None
        """
        return self.walk_activity.GetWalkCurveDefPoints(i_num_points, ad_points)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_walk_curve_def_points'
        # # vba_code = """
        # # Public Function get_walk_curve_def_points(walk_activity)
        # #     Dim iNumPoints (2)
        # #     walk_activity.GetWalkCurveDefPoints iNumPoints
        # #     get_walk_curve_def_points = iNumPoints
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def has_part_relation(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func HasPartRelation() As boolean
                | 
                |     Returns if there is any PartRelation
                | 
                |     Returns:
                |         bFlag TRUE, if there exist any Part-Relation

        :rtype: bool
        """
        return self.walk_activity.HasPartRelation()

    def set_walk_curve_def_points(self, i_num_points: int, ad_points: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetWalkCurveDefPoints(long iNumPoints,
                | CATSafeArrayVariant adPoints)
                | 
                |     This sets the Walk Path definition Point
                | 
                |     Parameters:
                | 
                |         iNumPoints
                |             Number of Coplanar-Points defining the Walk Path in Plane
                |             
                |         adPoints
                |             Point values x1,y1,z1 , x2,y2,z2, .... Area of Plane
                |             coordinates

        :param int i_num_points:
        :param tuple ad_points:
        :rtype: None
        """
        return self.walk_activity.SetWalkCurveDefPoints(i_num_points, ad_points)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_walk_curve_def_points'
        # # vba_code = """
        # # Public Function set_walk_curve_def_points(walk_activity)
        # #     Dim iNumPoints (2)
        # #     walk_activity.SetWalkCurveDefPoints iNumPoints
        # #     set_walk_curve_def_points = iNumPoints
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def update(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Update()
                | 
                |     This method is the key-method to create children-MoveToPostures for a
                |     created Walk.
                |     This is must be called after setting appropriate values for Walk Activity.

        :rtype: None
        """
        return self.walk_activity.Update()

    def __repr__(self):
        return f'WalkActivity(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.knowledge_interfaces.free_parameters import FreeParameters
from pycatia.knowledge_interfaces.knowledge_object import KnowledgeObject
from pycatia.knowledge_interfaces.optimization_constraints import OptimizationConstraints
from pycatia.knowledge_interfaces.real_param import RealParam


class Optimization(KnowledgeObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     KnowledgeInterfaces.KnowledgeObject
                |                         Optimization
                | 
                | Represents an Optimization object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.optimization = com_object

    @property
    def algorithm_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property AlgorithmType() As CatAlgorithmType
                | 
                |     Returns or sets the algorithm type. Currently available algorithms are
                |     gradient and simulatedAnnealing
                | 
                |     See also:
                |         CatAlgorithmType

        :return: enum cat_algorithm_type
        :rtype: int
        """

        return self.optimization.AlgorithmType

    @algorithm_type.setter
    def algorithm_type(self, value: int):
        """
        :param int value: enum cat_algorithm_type
        """

        self.optimization.AlgorithmType = value

    @property
    def constraints(self) -> OptimizationConstraints:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Constraints() As OptimizationConstraints (Read
                | Only)
                | 
                |     Returns the collection of optimization constraints.

        :rtype: OptimizationConstraints
        """

        return OptimizationConstraints(self.optimization.Constraints)

    @property
    def conv_speed(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ConvSpeed() As long
                | 
                |     Returns or sets the convergence speed for some gradients and the simulated
                |     annealing.

        :rtype: int
        """

        return self.optimization.ConvSpeed

    @conv_speed.setter
    def conv_speed(self, value: int):
        """
        :param int value:
        """

        self.optimization.ConvSpeed = value

    @property
    def free_parameters(self) -> FreeParameters:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property FreeParameters() As FreeParameters (Read Only)
                | 
                |     Returns the collection of the free parameters.

        :rtype: FreeParameters
        """

        return FreeParameters(self.optimization.FreeParameters)

    @property
    def max_evals_nb(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property MaxEvalsNb() As long
                | 
                |     Returns or sets the maximum number of model updates allowed during one run
                |     of the optimization.

        :rtype: int
        """

        return self.optimization.MaxEvalsNb

    @max_evals_nb.setter
    def max_evals_nb(self, value: int):
        """
        :param int value:
        """

        self.optimization.MaxEvalsNb = value

    @property
    def max_evals_wo_improvement(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property MaxEvalsWoImprovement() As long
                | 
                |     Returns or sets the maximum number of model updates without improvement of
                |     the problem solution during one run of the optimization.

        :rtype: int
        """

        return self.optimization.MaxEvalsWoImprovement

    @max_evals_wo_improvement.setter
    def max_evals_wo_improvement(self, value: int):
        """
        :param int value:
        """

        self.optimization.MaxEvalsWoImprovement = value

    @property
    def max_time(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property MaxTime() As long
                | 
                |     Returns or sets the maximum time allowed for one run of the optimization
                |     (in minutes).

        :rtype: int
        """

        return self.optimization.MaxTime

    @max_time.setter
    def max_time(self, value: int):
        """
        :param int value:
        """

        self.optimization.MaxTime = value

    @property
    def objective_parameter(self) -> RealParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ObjectiveParameter() As RealParam
                | 
                |     Returns or sets the objective parameter of the optimization. This parameter
                |     can not exist (in this case the get method returns E_FAIL) when the
                |     optimization contains only constraints and uses Simulated Annealing, or if the
                |     optimization feature doesn't contain all information necessary to be run.

        :rtype: RealParam
        """

        return RealParam(self.optimization.ObjectiveParameter)

    @objective_parameter.setter
    def objective_parameter(self, value: RealParam):
        """
        :param RealParam value:
        """

        self.optimization.ObjectiveParameter = value

    @property
    def optimization_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property OptimizationType() As CatOptimizationType
                | 
                |     Returns or sets the type of the optimization: minimum, maximum or target
                |     value searched on the objective parameter.
                | 
                |     See also:
                |         CatOptimizationType

        :return: enum cat_optimization_type
        :rtype: int
        """

        return self.optimization.OptimizationType

    @optimization_type.setter
    def optimization_type(self, value: int):
        """
        :param int value: enum cat_optimization_type
        """

        self.optimization.OptimizationType = value

    @property
    def target_value(self) -> RealParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property TargetValue() As RealParam (Read Only)
                | 
                |     Returns the objective parameter target value. (used only if the
                |     optimization type is a target value search)

        :rtype: RealParam
        """

        return RealParam(self.optimization.TargetValue)

    @property
    def use_max_evals_wo_improvement(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property UseMaxEvalsWoImprovement() As boolean
                | 
                |     Returns or sets if the number of updates without improvement of the
                |     solution has to be used as a termination criterion.

        :rtype: bool
        """

        return self.optimization.UseMaxEvalsWoImprovement

    @use_max_evals_wo_improvement.setter
    def use_max_evals_wo_improvement(self, value: bool):
        """
        :param bool value:
        """

        self.optimization.UseMaxEvalsWoImprovement = value

    @property
    def use_max_time(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property UseMaxTime() As boolean
                | 
                |     Returns or sets if max time has to be used as a termination criterion.

        :rtype: bool
        """

        return self.optimization.UseMaxTime

    @use_max_time.setter
    def use_max_time(self, value: bool):
        """
        :param bool value:
        """

        self.optimization.UseMaxTime = value

    def run(self, i_with_stop_dialog: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Run(boolean iWithStopDialog)
                | 
                |     Runs the optimization as it is defined. The stop dialog appears if argument
                |     is TRUE
                |     Before running, a check is made to ensure that the optimization feature
                |     contains enough information to run the optimization. In the case where some
                |     information is missing, this method returns E_FAIL
                |     WARNING : if argument is TRUE, the optimization is launched asynchronously, and you can not run
                |               several optimizations in this mode.

        :param bool i_with_stop_dialog:
        :rtype: None
        """
        return self.optimization.Run(i_with_stop_dialog)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'run'
        # # vba_code = """
        # # Public Function run(optimization)
        # #     Dim iWithStopDialog (2)
        # #     optimization.Run iWithStopDialog
        # #     run = iWithStopDialog
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Optimization(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_boundary_conditions import ABQBoundaryConditions
from pycatia.abq_automation_interfaces.abq_loads import ABQLoads
from pycatia.abq_automation_interfaces.abq_step import ABQStep


class ABQHeatTransferStep(ABQStep):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQStep
                |                         ABQHeatTransferStep
                | 
                | Represents an Abaqus heat transfer step (ABQHeatTransferStep)
                | object.
                | Role: Access an Abaqus heat transfer step object or determine its
                | properties.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_heat_transfer_step = com_object

    @property
    def boundary_conditions(self) -> ABQBoundaryConditions:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property BoundaryConditions() As ABQBoundaryConditions (Read
                | Only)
                | 
                |     Returns the ABQBoundaryConditions container associated with the
                |     step.
                | 
                |     Example:
                |         This example retrieves the ABQBoundaryConditions container
                |         abqBCs.
                | 
                |          Dim abqHeatStep As ABQHeatTransferStep 
                |          Dim abqBCs As ABQBoundaryConditions
                |          Set abqBCs = abqHeatStep.BoundaryConditions

        :rtype: ABQBoundaryConditions
        """

        return ABQBoundaryConditions(self.abq_heat_transfer_step.BoundaryConditions)

    @property
    def delta_maximum(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Deltmx() As double
                | 
                |     Sets or returns the maximum temperature change to be allowed in an
                |     increment during a transient heat transfer analysis.
                | 
                |     Returns:
                |         Maximum temperature change to be allowed in an
                |         increment

        :rtype: float
        """

        return self.abq_heat_transfer_step.Deltmx

    @delta_maximum.setter
    def delta_maximum(self, value: float):
        """
        :param float value:
        """

        self.abq_heat_transfer_step.Deltmx = value

    @property
    def description(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Description() As CATBSTR
                | 
                |     Sets or returns the description of the step.
                | 
                |     Returns:
                |         The description of the step

        :rtype: str
        """

        return self.abq_heat_transfer_step.Description

    @description.setter
    def description(self, value: str):
        """
        :param str value:
        """

        self.abq_heat_transfer_step.Description = value

    @property
    def end_step_on_temp_change(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property EndStepOnTempChange() As boolean
                | 
                |     Sets or returns whether the step should end when steady state is reached. A
                |     value of true indicates that the step will end.
                | 
                |     Returns:
                |         A boolean indicating whether the step will end when steady state is
                |         reached

        :rtype: bool
        """

        return self.abq_heat_transfer_step.EndStepOnTempChange

    @end_step_on_temp_change.setter
    def end_step_on_temp_change(self, value: bool):
        """
        :param bool value:
        """

        self.abq_heat_transfer_step.EndStepOnTempChange = value

    @property
    def initial_inc(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property InitialInc() As double
                | 
                |     Sets or returns the initial increment size.
                | 
                |     Returns:
                |         The initial increment size

        :rtype: float
        """

        return self.abq_heat_transfer_step.InitialInc

    @initial_inc.setter
    def initial_inc(self, value: float):
        """
        :param float value:
        """

        self.abq_heat_transfer_step.InitialInc = value

    @property
    def loads(self) -> ABQLoads:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Loads() As ABQLoads (Read Only)
                | 
                |     Returns the ABQLoads container associated with the step.
                | 
                |     Example:
                |         The following example retrieves the ABQLoads container
                |         abqLoads:
                | 
                |          Dim abqHeatStep As ABQHeatTransferStep
                |          Dim abqLoads As ABQLoads
                |          Set abqLoads = abqHeatStep.Loads

        :rtype: ABQLoads
        """

        return ABQLoads(self.abq_heat_transfer_step.Loads)

    @property
    def max_inc(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MaxInc() As double
                | 
                |     Sets or returns the maximum increment size if
                |     TimeIncrementationMethod=AUTO_INCREMENT.
                | 
                |     Returns:
                |         The maximum increment size

        :rtype: float
        """

        return self.abq_heat_transfer_step.MaxInc

    @max_inc.setter
    def max_inc(self, value: float):
        """
        :param float value:
        """

        self.abq_heat_transfer_step.MaxInc = value

    @property
    def max_num_inc(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MaxNumInc() As short
                | 
                |     Sets or returns the maximum number of increments if
                |     TimeIncrementationMethod=AUTO_INCREMENT.
                | 
                |     Returns:
                |         The maximum number of increments

        :rtype: int
        """

        return self.abq_heat_transfer_step.MaxNumInc

    @max_num_inc.setter
    def max_num_inc(self, value: int):
        """
        :param int value:
        """

        self.abq_heat_transfer_step.MaxNumInc = value

    @property
    def min_inc(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MinInc() As double
                | 
                |     Sets or returns the minimum increment size if
                |     TimeIncrementationMethod=AUTO_INCREMENT.
                | 
                |     Returns:
                |         The minimum increment size

        :rtype: float
        """

        return self.abq_heat_transfer_step.MinInc

    @min_inc.setter
    def min_inc(self, value: float):
        """
        :param float value:
        """

        self.abq_heat_transfer_step.MinInc = value

    @property
    def maximum_delta_emission(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Mxdem() As double
                | 
                |     Sets or returns the maximum allowable emissivity change with temperature
                |     and field variables during an increment.
                | 
                |     Returns:
                |         The maximum allowable emissivity change

        :rtype: float
        """

        return self.abq_heat_transfer_step.Mxdem

    @maximum_delta_emission.setter
    def maximum_delta_emission(self, value: float):
        """
        :param float value:
        """

        self.abq_heat_transfer_step.Mxdem = value

    @property
    def response(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Response() As Response_Type
                | 
                |     Sets or returns the response type.
                | 
                |     Returns:
                |         The response type
                | 
                |          
                |          
                |         Legal values:
                |           STEADY_STATE  
                |           TRANSIENT

        :return: enum response_type
        :rtype: int
        """

        return self.abq_heat_transfer_step.Response

    @response.setter
    def response(self, value: int):
        """
        :param int value: enum response_type
        """

        self.abq_heat_transfer_step.Response = value

    @property
    def time_incrementation_method(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TimeIncrementationMethod() As Incrementation_Type
                | 
                |     Sets or returns the incrementation type.
                | 
                |     Returns:
                |         The incrementation type
                | 
                |          
                |          
                |         Legal values:
                |           AUTO_INCREMENT
                |           FIXED_INCREMENT

        :return: enum incrementation_type
        :rtype: int
        """

        return self.abq_heat_transfer_step.TimeIncrementationMethod

    @time_incrementation_method.setter
    def time_incrementation_method(self, value: int):
        """
        :param int value: enum incrementation_type
        """

        self.abq_heat_transfer_step.TimeIncrementationMethod = value

    @property
    def time_period(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TimePeriod() As double
                | 
                |     Sets or returns the step time.
                | 
                |     Returns:
                |         The step time

        :rtype: float
        """

        return self.abq_heat_transfer_step.TimePeriod

    @time_period.setter
    def time_period(self, value: float):
        """
        :param float value:
        """

        self.abq_heat_transfer_step.TimePeriod = value

    def __repr__(self):
        return f'ABQHeatTransferStep(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_fields import ABQFields
from pycatia.abq_automation_interfaces.abq_mass_scalings import ABQMassScalings
from pycatia.abq_automation_interfaces.abq_step import ABQStep


class ABQInitialStep(ABQStep):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQStep
                |                         ABQInitialStep
                | 
                | Represents an Abaqus initial step (ABQInitialStep) object.
                | Role: Access an Abaqus initial step object or determine its
                | properties.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_initial_step = com_object

    @property
    def fields(self) -> ABQFields:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Fields() As ABQFields (Read Only)
                | 
                |     Returns the ABQFields container associated with the step.
                | 
                |     Example:
                |         This example retrieves the ABQFields container
                |         abqFields.
                | 
                |          Dim abqInitialStep As ABQInitialStep 
                |          Dim abqFields As ABQFields
                |          Set abqFields = abqInitialStep.Fields

        :rtype: ABQFields
        """

        return ABQFields(self.abq_initial_step.Fields)

    @property
    def mass_scalings(self) -> ABQMassScalings:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MassScalings() As ABQMassScalings (Read Only)
                | 
                |     Returns the ABQMassScalings container associated with the
                |     step.
                | 
                |     Example:
                |         The following example retrieves the ABQMassScalings container
                |         abqScalings:
                | 
                |          Dim abqInitialStep As ABQInitialStep 
                |          Dim abqScalings As ABQMassScalings
                |          Set abqScalings = abqInitialStep.MassScalings

        :rtype: ABQMassScalings
        """

        return ABQMassScalings(self.abq_initial_step.MassScalings)

    def __repr__(self):
        return f'ABQInitialStep(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.move import Move
from pycatia.in_interfaces.position import Position
from pycatia.osm_interfaces.product_scene import ProductScene
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject


class Scene(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Scene
                | 
                | Represent the scene.
                | A scene stores a state of a product in a given
                | ProductDocument.
                | 
                | This state is composed of product properties, graphical attibutes, activation
                | status and position for each component of the product.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.scene = com_object

    def get_definition(self, i_product: Product) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDefinition(Product iProduct) As CATBSTR
                | 
                |     Returns the product's definition.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The product. 
                | 
                |     Returns:
                |         The product's definition. 
                |     Example:
                | 
                |              This example retrieves the Engine product's
                |              definition
                |             in the Configuration1 scene.
                |             
                | 
                |             Dim Definition As String
                |             Definition = Configuration1.GetDefinition(Engine)

        :param Product i_product:
        :rtype: str
        """
        return self.scene.GetDefinition(i_product.com_object)

    def get_description(self, i_product: Product) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDescription(Product iProduct) As CATBSTR
                | 
                |     Returns the product's description.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The product. 
                | 
                |     Returns:
                |         The product's description. 
                |     Example:
                | 
                |              This example retrieves the Engine product's
                |              description
                |             in the Configuration1 scene.
                |
                |             Dim Description As String
                |             Description = Configuration1.GetDescription(Engine)

        :param Product i_product:
        :rtype: str
        """
        return self.scene.GetDescription(i_product.com_object)

    def get_master_shape_representation(self, i_product: Product, i_load_if_necessary: bool) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMasterShapeRepresentation(Product iProduct,
                | boolean iLoadIfNecessary) As CATBaseDispatch
                | 
                |     Retrieves the product's master shape representation.
                | 
                |     Parameters:
                | 
                |         iProduct.
                |             The product 
                |         iLoadIfNecessary
                |             Parameter to set to True if the master shape representation should
                |             be loaded to determine if it exists, or to False otherwise.
                |
                |     Returns:
                |         The product's master shape representation. 
                |     Example:
                | 
                |              This example retrieves the Engine product's master shape
                |              representation
                |             in the Configuration1 scene.
                |
                |             Dim MSRep As Object
                |             Set MSRep = Configuration1.GetMasterShapeRepresentation(Engine)

        :param Product i_product:
        :param bool i_load_if_necessary:
        :rtype: AnyObject
        """
        return self.scene.GetMasterShapeRepresentation(i_product.com_object, i_load_if_necessary)

    def get_move(self, i_product: Product) -> Move:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMove(Product iProduct) As Move
                | 
                |     Returns the product's move object. The move object is aggregated by the
                |     product object and itself aggregates a movable object to which you can apply a
                |     move transformation by means of an isometry matrix. It moves your product
                |     master shape representation according to this isometry.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The product 
                | 
                |     Returns:
                |         The move. 
                |     Example:
                | 
                |              This example retrieves the EngineMove move from the Engine
                |              product
                |             in the Configuration1 scene.
                |
                |             Dim EngineMove As Move
                |             Set EngineMove = Configuration1.GetMove(Engine)

        :param Product i_product:
        :rtype: Move
        """
        return Move(self.scene.GetMove(i_product.com_object))

    def get_nomenclature(self, i_product: Product) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetNomenclature(Product iProduct) As CATBSTR
                | 
                |     Returns the product's nomenclature.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The product. 
                | 
                |     Returns:
                |         The product's nomenclature. 
                |     Example:
                | 
                |              This example retrieves the Engine product's
                |              nomenclature
                |             in the Configuration1 scene.
                |
                |             Dim Nomenclature As String
                |             Nomenclature = Configuration1.GetNomenclature(Engine)

        :param Product i_product:
        :rtype: str
        """
        return self.scene.GetNomenclature(i_product.com_object)

    def get_part_number(self, i_product: Product) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPartNumber(Product iProduct) As CATBSTR
                | 
                |     Returns the product's part number.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The product. 
                | 
                |     Returns:
                |         The product's part number. 
                |     Example:
                | 
                |              This example retrieves the Engine product's part
                |              number
                |             in the Configuration1 scene.
                |
                |             Dim PartNumber As String
                |             PartNumber = Configuration1.GetPartNumber(Engine)

        :param Product i_product:
        :rtype: str
        """
        return self.scene.GetPartNumber(i_product.com_object)

    def get_position(self, i_product: Product) -> Position:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPosition(Product iProduct) As Position
                | 
                |     Returns the product's position object in the scene. The position object is
                |     the object aggregated by the product object that holds the position of the
                |     master shape representation in the space.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The product 
                | 
                |     Returns:
                |         The position. 
                |     Example:
                | 
                |              This example retrieves the EnginePosition position from the Engine
                |              product
                |             in the Configuration1 scene.
                |
                |             Dim EnginePosition As Position
                |             Set EnginePosition = Configuration1.GetPosition(Engine)

        :param Product i_product:
        :rtype: Position
        """
        return Position(self.scene.GetPosition(i_product.com_object))

    def get_revision(self, i_product: Product) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRevision(Product iProduct) As CATBSTR
                | 
                |     Returns the product's revision number.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The product. 
                | 
                |     Returns:
                |         The product's revision number. 
                |     Example:
                | 
                |              This example retrieves the Engine product's revision
                |              number
                |             in the Configuration1 scene.
                |
                |             Dim Revision As String
                |             Revision = Configuration1.GetRevision(Engine)

        :param Product i_product:
        :rtype: str
        """
        return self.scene.GetRevision(i_product.com_object)

    def get_source(self, i_product: Product) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSource(Product iProduct) As CatProductSource
                | 
                |     Returns the product's source.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The product. 
                | 
                |     Returns:
                |         The product's source. 
                |     Example:
                | 
                |              This example retrieves the Engine product's
                |              source
                |             in the Configuration1 scene.
                |
                |             Dim Source
                |             Source = Configuration1.GetSource(Engine)

        :param Product i_product:
        :rtype: enum cat_product_source
        :rtype: int
        """
        return self.scene.GetSource(i_product.com_object)

    def has_a_master_shape_representation(self, i_product: Product) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func HasAMasterShapeRepresentation(Product iProduct) As
                | boolean
                | 
                |     Returns whether the product has a master shape representation in the
                |     scene.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The product 
                | 
                |     Returns:
                |         True if the product has a master shape representation.
                |         
                |     Example:
                | 
                |              This example returns whether the Engine product has a master shape
                |              representation
                |             in the Configuration1 scene.
                |
                |             HasMSRep = Configuration1.HasAMasterShapeRepresentation(Engine)

        :param Product i_product:
        :rtype: bool
        """
        return self.scene.HasAMasterShapeRepresentation(i_product.com_object)

    def upgrade_to_full(self) -> ProductScene:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func UpgradeToFull() As ProductScene
                | 
                |     Create a ProductScene in Full mode from the current Scene.
                | 
                |     Returns:
                |         The new ProductScene. 
                |     Example:
                | 
                |              This example creates the FullScene ProductScene from the
                |              Configuration1 scene.
                |
                |             Dim FullScene As ProductScene
                |             Set FullScene = Configuration1.UpgradeToFull

        :rtype: ProductScene
        """
        return ProductScene(self.scene.UpgradeToFull())

    def upgrade_to_partial(self) -> ProductScene:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func UpgradeToPartial() As ProductScene
                | 
                |     Create a ProductScene in Partial mode from the current
                |     Scene.
                | 
                |     Returns:
                |         The new ProductScene. 
                |     Example:
                | 
                |              This example creates the PartialScene ProductScene from the
                |              Configuration1 scene.
                |
                |             Dim PartialScene As ProductScene
                |             Set PartialScene = Configuration1.UpgradeToPartial

        :rtype: ProductScene
        """
        return ProductScene(self.scene.UpgradeToPartial())

    def __repr__(self):
        return f'Scene(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject


class HomePosition(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     HomePosition
                | 
                | Interface representing a device's Home Position.
                | 
                | Role: This interface is used to interact with a device's home positions. This
                | includes devices created in using V5 mechanisms or imported from DENEB
                | D5.
                | A home position is a list of values, each value being associated to each
                | Degrees Of Freedom(DOF) of the device, defining a state for the device (The
                | list size matches the number of commands that can be
                | simulated).
                | 
                | With home positions, it is possible to define Tool tips. A Tool tip is a
                | specific device part meant to be in contact with product(s). User may define
                | some device parts as tool tips so that, when they are in collision, the clash
                | is ignored. Tool tips are excluded from clash analysis in tools like DPM
                | Body-in-White's weldgun search.
                | 
                | The following code snippet can be used to obtain a home position from a
                | device.
                | 
                |    Dim objDevice As BasicDevice
                |    set objDevice = CATIA.ActiveDocument.Product.GetTechnologicalObject("BasicDevice")
                |    Dim ListOfHomePositions()
                |    objDevice.GetHomePositions ListOfHomePositions
                |    Dim homePos as HomePosition
                |    For Each homePos In ListOfHomePositions
                |       ...
                |    Next
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.home_position = com_object

    def get_associated_tool_tip(self, o_tip_list: tuple) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAssociatedToolTip(CATSafeArrayVariant oTipList)
                | 
                |     Get the tooltips associated with the home position.
                | 
                |     Parameters:
                | 
                |         oTipList
                |             This out parameter contains list of tooltips associated with the
                |             home position. The list contains a set of device parts.
                |
                |     Example:
                |
                |            ' declaration of 1 list of products and 1 home
                |            position
                |            Dim MyToolTips() As Product
                |            Dim MyHomePosition As HomePosition
                | 
                |            ' valuation of variables
                |            Set MyHomePosition = ...
                | 
                |            ' retrieval of tool tips as part of product array
                |            MyHomePosition.GetAssociatedToolTip( MyToolTips )
                | 
                |            ' start a loop displaying the name of each tool tip
                |            For Each toolTip In toolTips
                |                'warning: MsgBox is a modal dialog: it requires user
                |                interactions!!
                |                MsgBox toolTip.PartNumber = ...
                |            Next

        :param tuple o_tip_list:
        :rtype: Product
        """
        return Product(self.home_position.GetAssociatedToolTip(o_tip_list))
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_associated_tool_tip'
        # # vba_code = """
        # # Public Function get_associated_tool_tip(home_position)
        # #     Dim oTipList (2)
        # #     home_position.GetAssociatedToolTip oTipList
        # #     get_associated_tool_tip = oTipList
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_dof_values(self, o_values: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetDOFValues(CATSafeArrayVariant oValues)
                | 
                |     Get the DOF values for the home position.
                | 
                |     Parameters:
                | 
                |         oValues
                |             This contains a list of the current DOF values. Please note that
                |             values are expressed as:
                | 
                |                 meters for length values
                |                 radians for angle values
                | 
                |             angles in radians. 
                | 
                |     Example:
                |
                |            Dim objDevice As BasicDevice
                |            set objDevice = CATIA.ActiveDocument.Product.GetTechnologicalObject("BasicDevice")
                |            Dim ListOfHomePositions() 
                |            objDevice.GetHomePositions ListOfHomePositions
                |            Dim homePos as HomePosition  
                |            'define an empty array to store the values
                |            Dim DOFValues ()
                |            For Each homePos In ListOfHomePositions
                |               homePos.GetDOFValues DOFValues 
                |               For i = 0 to ubound (DOFValues)
                |                  ...
                |               Next
                |            Next

        :param tuple o_values:
        :rtype: None
        """
        return self.home_position.GetDOFValues(o_values)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_dof_values'
        # # vba_code = """
        # # Public Function get_dof_values(home_position)
        # #     Dim oValues (2)
        # #     home_position.GetDOFValues oValues
        # #     get_dof_values = oValues
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_associated_tool_tip(self, i_tip_list: tuple) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAssociatedToolTip(CATSafeArrayVariant iTipList)
                | 
                |     Set the tool tip associated with the home position.
                | 
                |     Parameters:
                | 
                |         iTipList
                |             This parameter contains list of associated tooltips (device parts
                |             meant to be ignored during clash analysis). 
                | 
                |     Example:
                |
                |            ' declaration of 2 products and 1 home position
                |            Dim MyPart1 As Product
                |            Dim MyPart2 As Product
                |            Dim MyHomePosition As HomePosition
                | 
                |            ' valuation of variables
                |            Set MyPart1 = ...
                |            Set MyPart2 = ...
                |            Set MyHomePosition = ...
                | 
                |            ' defining the tool tips through an array
                |            Dim MyToolTips(1) As Product
                |            Set MyToolTips(0) = MyPart1
                |            Set MyToolTips(1) = MyPart2
                |            MyHomePosition.SetAssociatedToolTip( MyToolTips )

        :param tuple i_tip_list:
        :rtype: Product
        """
        return Product(self.home_position.SetAssociatedToolTip(i_tip_list))
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_associated_tool_tip'
        # # vba_code = """
        # # Public Function set_associated_tool_tip(home_position)
        # #     Dim iTipList (2)
        # #     home_position.SetAssociatedToolTip iTipList
        # #     set_associated_tool_tip = iTipList
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_dof_values(self, i_values: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDOFValues(CATSafeArrayVariant iValues)
                | 
                |     Set the DOF values for the home position.
                | 
                |     Parameters:
                | 
                |         oValues
                |             This contains a list of the current DOF values. Please note that
                |             values are expressed as:
                | 
                |                 meters for length values
                |                 radians for angle values
                | 
                |     Example:
                |
                |            Dim DOFValues (6)
                |            For i = 0 to 5
                |               'Store value in radians
                |               DOFValues(i) = 10 * i * (pi / 180.0)
                |            next
                |            'Note: to obtain homePos, please refer to example in
                |            GetDOFValues
                |            homePos.SetDOFValues DOFValues

        :param tuple i_values:
        :rtype: None
        """
        return self.home_position.SetDOFValues(i_values)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_dof_values'
        # # vba_code = """
        # # Public Function set_dof_values(home_position)
        # #     Dim iValues (2)
        # #     home_position.SetDOFValues iValues
        # #     set_dof_values = iValues
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'HomePosition(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.analysis_interfaces.analysis_set import AnalysisSet


class AnalysisAdaptivityManager(AnalysisSet):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATAnalysisInterfaces.AnalysisSet
                |                         AnalysisAdaptivityManager
                | 
                | The interface to access a CATIAAnalysisAdaptivityManager.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.analysis_adaptivity_manager = com_object

    def run(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Run()
                | 
                |     Run the adaptivity process.

        :rtype: None
        """
        return self.analysis_adaptivity_manager.Run()

    def __repr__(self):
        return f'AnalysisAdaptivityManager(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator

from pycatia.drafting_interfaces.drawing_sheet import DrawingSheet
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class DrawingSheets(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     DrawingSheets
                | 
                | A collection of all the drawing sheets currently managed by the drawing
                | document.
                | 
                | Warning: This interface is not available with 2D Layout for 3D
                | Design.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=DrawingSheet)
        self.drawing_sheets = com_object

    @property
    def active_sheet(self) -> DrawingSheet:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ActiveSheet() As DrawingSheet (Read Only)
                | 
                |     Returns the active drawing sheet of the drawing document.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         The following example retrieves in SheetToWorkIn the active drawing
                |         sheet of the drawing document named CATDrawing1.
                | 
                |          Dim MyDrawingDoc As Document
                |          Set MyDrawingDoc = CATIA.Documents.Item("CATDrawing1")
                |          Dim SheetToWorkIn As DrawingSheet
                |          Set SheetToWorkIn =  MyDrawingDoc.Sheets.ActiveSheet

        :rtype: DrawingSheet
        """

        return DrawingSheet(self.drawing_sheets.ActiveSheet)

    def add(self, i_drawing_sheet_name: str) -> DrawingSheet:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Add(CATBSTR iDrawingSheetName) As DrawingSheet
                | 
                |     Creates a drawing sheet and adds it to the DrawingSheets collection. This
                |     drawing sheet becomes the active one.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Parameters:
                | 
                |         iDrawingSheetName
                |             The name to assign to the created DrawingSheet object
                |             
                | 
                |     Returns:
                |         The created drawing sheet 
                |     Example:
                |         The following example creates a drawing sheet named FirstSheet and
                |         retrieved in MySheet in the drawing sheet collection of the document named
                |         CATDrawing1.
                | 
                |          Dim MyDrawingDoc As Document
                |          Set MyDrawingDoc = CATIA.Documents.Item("CATDrawing1")
                |          Dim MySheet As DrawingSheet
                |          Set MySheet = MyDrawingDoc.Sheets.Add("FirstSheet")

        :param str i_drawing_sheet_name:
        :rtype: DrawingSheet
        """
        return DrawingSheet(self.drawing_sheets.Add(i_drawing_sheet_name))

    def add_detail(self, i_drawing_sheet_name: str) -> DrawingSheet:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func AddDetail(CATBSTR iDrawingSheetName) As DrawingSheet
                | 
                |     Creates a detail drawing sheet and adds it to the DrawingSheets collection.
                |     This detail drawing sheet becomes the active one.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Parameters:
                | 
                |         iDrawingSheetName
                |             The name to assign to the created detail DrawingSheet object
                |             
                | 
                |     Returns:
                |         The created drawing sheet 
                |     Example:
                |         The following example creates a detail drawing sheet named FirstSheet
                |         and retrieved in MySheet in the drawing sheet collection of the document named
                |         CATDrawing1.
                | 
                |          Dim MyDrawingDoc As Document
                |          Set MyDrawingDoc = CATIA.Documents.Item("CATDrawing1")
                |          Dim MySheet As DrawingSheet
                |          Set MySheet = MyDrawingDoc.Sheets.Add("FirstSheet")

        :param str i_drawing_sheet_name:
        :rtype: DrawingSheet
        """
        return DrawingSheet(self.drawing_sheets.AddDetail(i_drawing_sheet_name))

    def item(self, i_index: cat_variant) -> DrawingSheet:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Item(CATVariant iIndex) As DrawingSheet
                | 
                |     Returns a drawing sheet using its index or its name from the DrawingSheets
                |     collection.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the drawing sheet to retrieve from the
                |             collection of drawing sheets. As a numerics, this index is the rank of the
                |             drawing sheet in the collection. The index of the first drawing sheet in the
                |             collection is 1, and the index of the last drawing sheet is Count. As a string,
                |             it is the name you assigned to the drawing sheet using the
                |             
                | 
                |         AnyObject.Name property or when creating it using the Add method.
                |         
                |     Returns:
                |         The retrieved drawing sheet 
                |     Example:
                |         This example retrieves in ThisDrawingSheet the third drawing sheet, and
                |         in ThatDrawingSheet the drawing sheet named MySheet in the drawing sheet
                |         collection of the active document, supposed to be a drawing
                |         document.
                | 
                |          Dim ThisDrawingSheet As DrawingSheet
                |          Set ThisDrawingSheet = CATIA.ActiveDocument.Sheets.Item(3)
                |          Dim ThatDrawingSheet As DrawingSheet
                |          Set ThatDrawingSheet = CATIA.ActiveDocument.Sheets.Item("MySheet")

        :param cat_variant i_index:
        :rtype: DrawingSheet
        """
        return DrawingSheet(self.drawing_sheets.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes a drawing sheet from the DrawingSheets collection.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the drawing sheet to remove from the
                |             collection of drawing sheets. As a numerics, this index is the rank of the
                |             drawing sheet in the collection. The index of the first drawing sheet in the
                |             collection is 1, and the index of the last drawing sheet is Count. As a string,
                |             it is the name you assigned to the drawing sheet using the
                |             
                | 
                |         AnyObject.Name property or when creating it using the Add method.
                |         
                |     Example:
                |         The following example removes the second drawing sheet and the drawing
                |         sheet named SheetToBeRemoved in the drawing sheet collection of the active
                |         document, supposed to be a drawing document.
                | 
                |         CATIA.ActiveDocument.DrawingSheets.Remove(2)
                |         CATIA.ActiveDocument.DrawingSheets.Remove("SheetToBeRemoved")

        :param cat_variant i_index:
        :return: None
        """
        return self.drawing_sheets.Remove(i_index)

    def __getitem__(self, n: int) -> DrawingSheet:
        if (n + 1) > self.count:
            raise StopIteration

        return DrawingSheet(self.drawing_sheets.Item(n + 1))

    def __iter__(self) -> Iterator[DrawingSheet]:
        for i in range(self.count):
            yield self.child_object(self.com_object.Item(i + 1))

    def __repr__(self):
        return f'DrawingSheets(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.drafting_interfaces.drawing_dimension import DrawingDimension
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.cat_tps_interfaces.controlled_radius import ControlledRadius
from pycatia.cat_tps_interfaces.dimension_limit import DimensionLimit
from pycatia.cat_tps_interfaces.dimension_pattern import DimensionPattern
from pycatia.cat_tps_interfaces.envelope_condition import EnvelopeCondition


class Dimension3D(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Dimension3D
                | 
                | Interface Managing Semantic Dimension.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.dimension_3d = com_object

    def controled_radius(self) -> ControlledRadius:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ControledRadius() As ControledRadius
                | 
                |     Get the Dimension on the Controled Radius interface.
                | 
                |     Parameters:
                | 
                |         oContRadius
                |             The Controled Radius.

        :rtype: ControledRadius
        """
        return ControlledRadius(self.dimension_3d.ControlledRadius())

    def dimension_limit(self) -> DimensionLimit:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func DimensionLimit() As DimensionLimit
                | 
                |     Gets the Dimension on the DimensionLimit interface.
                | 
                |     Parameters:
                | 
                |         oDimLim
                |             The Dimension Limits.

        :rtype: DimensionLimit
        """
        return DimensionLimit(self.dimension_3d.DimensionLimit())

    def dimension_pattern(self) -> DimensionPattern:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func DimensionPattern() As DimensionPattern
                | 
                |     Gets the Dimension on the DimensionPattern interface.
                | 
                |     Parameters:
                | 
                |         oDimPatt
                |             The Dimension Pattern.

        :rtype: DimensionPattern
        """
        return DimensionPattern(self.dimension_3d.DimensionPattern())

    def envelope_condition(self) -> EnvelopeCondition:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func EnvelopCondition() As EnvelopCondition
                | 
                |     Gets the Dimension on the EnvelopCondition interface.
                | 
                |     Parameters:
                | 
                |         oEnvCond
                |             The Envelop Condition.

        :rtype: EnvelopCondition
        """
        return EnvelopeCondition(self.dimension_3d.EnvelopeCondition())

    def get_2d_annot(self) -> DrawingDimension:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Get2dAnnot() As DrawingDimension
                | 
                |     Retrieves Drafting Dimension.
                | 
                |     Parameters:
                | 
                |         oDim
                |             The Drafting Dimension.

        :rtype: DrawingDimension
        """
        return DrawingDimension(self.dimension_3d.Get2dAnnot())

    def has_a_controlled_radius(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func HasAControledRadius() As boolean
                | 
                |     Checks if the Dimension has a Controled Radius.
                | 
                |     Parameters:
                | 
                |         oHasConRad
                | 
                |                 TRUE: The dimension has a Controled Radius
                |                 FALSE: The dimension has not a Controled
                |                 Radius

        :rtype: bool
        """
        return self.dimension_3d.HasAControledRadius()

    def has_an_envelope_condition(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func HasAnEnvelopCondition() As boolean
                | 
                |     Checks if the Annotation has an Envelop Condition.
                | 
                |     Parameters:
                | 
                |         oHasEnvCond
                | 
                |                 TRUE: The dimension has an Envelop Condition
                |                 FALSE: The dimension has not an Envelop
                |                 Condition

        :rtype: bool
        """
        return self.dimension_3d.HasAnEnvelopCondition()

    def has_dimension_limit(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func HasDimensionLimit() As boolean
                | 
                |     Checks if the Dimension has a Dimension Limit.
                | 
                |     Parameters:
                | 
                |         oHasDimLim
                | 
                |                 TRUE: Dimension Limit exists
                |                 FALSE: Dimension Limit does not exist

        :rtype: bool
        """
        return self.dimension_3d.HasDimensionLimit()

    def is_a_dimension_pattern(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsADimensionPattern() As boolean
                | 
                |     Checks if the Semantic Dimension is a Dimension Pattern.
                | 
                |     Parameters:
                | 
                |         oIsADimPatt
                | 
                |                 TRUE: The dimension is a Dimension Pattern
                |                 FALSE: The dimension is not a Dimension
                |                 Pattern

        :rtype: bool
        """
        return self.dimension_3d.IsADimensionPattern()

    def move_value(self, x: float, y: float, sub_part: int, dim_angle_behavior: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub MoveValue(double X,
                | double Y,
                | long SubPart,
                | long DimAngleBehavior)
                | 
                |     Moves the dimension value at a given point.
                | 
                |     Returns:
                |         HRESULT error returned code If the modification of the vertical offset value can not be performed because the parameter is locked in the current standard, the method return HRESULT = S_READ_ONLY. 
                |     Parameters:
                | 
                |         X
                |             Point abscissa on which the dimension value will be positionned.
                |             
                |         Y
                |             Point ordinate on which the dimension value will be positionned.
                |             
                |         SubPart
                |             Defines which part of the dimension should be
                |             moved
                |             -1 = Value (vertical move is take account according ptPos coordinates)
                |             0 = Both dimension line and value
                |             1 = Value
                |             2 = Dimension line
                |             3 = Secondary part
                |             4 = Secondary part and value
                |             5 = Secondary part and dimension line
                |             6 = Secondary part, dimension line and value
                |             7 = Value leader (for dimension line with leader one part or two parts) 
                |         DimAngleBehavior
                |             Defines angle dimension line behavior.
                |             0 = Sector angle is switched when ptPos is in opposite sector (Default)
                |             1 = Sector angle is kept what ever ptPos placement 
                |         Example:
                |             This example move dimension value MyDimension
                |             path.
                | 
                |              MyDimension.MoveValue(X, Y, SubPart,
                |              DimAngleBehavior)

        :param float x:
        :param float y:
        :param int sub_part:
        :param int dim_angle_behavior:
        :rtype: None
        """
        return self.dimension_3d.MoveValue(x, y, sub_part, dim_angle_behavior)

    def __repr__(self):
        return f'Dimension3D(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_app_connection import SchAppConnection
from pycatia.cat_sch_platform_interfaces.sch_app_connector import SchAppConnector
from pycatia.cat_sch_platform_interfaces.sch_grr_route import SchGRRRoute
from pycatia.cat_sch_platform_interfaces.sch_list_of_doubles import SchListOfDoubles
from pycatia.system_interfaces.any_object import AnyObject


class SchRoute(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchRoute
                | 
                | Manage a schematic route data.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_route = com_object

    def add_points(self, i_grr: SchGRRRoute, i_l_db2_pt_path_to_add: tuple, i_after_which_pt_num: int) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddPoints(SchGRRRoute iGRR,
                | CATSafeArrayVariant iLDb2PtPathToAdd,
                | long iAfterWhichPtNum)
                | 
                |     Add a list of point to a route. Modify the route according to the route
                |     mode
                | 
                |     Parameters:
                | 
                |         iGRR
                |             graphical primitive of the route to add points to (if NULL, assume
                |             there is only one graphical primitive) 
                |         iLDbPtPathToAdd
                |             A list of X-Y coordinates of points to be added. 2 doubles per
                |             point. 
                |         iAfterWhichPtNum
                |             The point number to add the points after. Use 0 to indicate adding
                |             before the first point. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchRoute
                |          Dim objArg1 As SchGRRRoute
                |          Dim dbVar2(x) As CATSafeArrayVariant
                |          Dim intVar4 As Integer
                |           ...
                |          objThisIntf.AddPointsobjArg1,dbVar2,intVar4

        :param SchGRRRoute i_grr:
        :param tuple i_l_db2_pt_path_to_add:
        :param int i_after_which_pt_num:
        :rtype: tuple
        """
        return self.sch_route.AddPoints(i_grr.com_object, i_l_db2_pt_path_to_add, i_after_which_pt_num)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_points'
        # # vba_code = """
        # # Public Function add_points(sch_route)
        # #     Dim iGRR (2)
        # #     sch_route.AddPoints iGRR
        # #     add_points = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def branch(
            self,
            i_grr_main: SchGRRRoute,
            i_sch_branch_route: 'SchRoute',
            i_sch_branch_route_cntr: SchAppConnector,
            o_branch_cntn: SchAppConnection,
            o_new_branch_cntr: SchAppConnector
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Branch(SchGRRRoute iGRRMain,
                | SchRoute iSchBranchRoute,
                | SchAppConnector iSchBranchRouteCntr,
                | SchAppConnection oBranchCntn,
                | SchAppConnector oNewBranchCntr)
                | 
                |     Create a branch from this route.
                | 
                |     Parameters:
                | 
                |         iGRRMain
                |             graphical primitive of the "this" route to branch from (if NULL,
                |             assume there is only one graphical primitive) 
                |         iSchBranchRoute
                |             The route to create a branch connection to (from this route)
                |             
                |         iSchBranchRouteCntr
                |             The extremity connector of the branch 
                |         oBranchCntn
                |             The branch connection created 
                |         oNewBranchCntr
                |             The new branch connector created on "this" route 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchRoute
                |          Dim objArg1 As SchGRRRoute
                |          Dim objArg2 As SchRoute
                |          Dim objArg3 As SchAppConnector
                |          Dim objArg4 As SchAppConnection
                |          Dim objArg5 As SchAppConnector
                |           ...
                |          objThisIntf.BranchobjArg1,objArg2,objArg3,objArg4,objArg5

        :param SchGRRRoute i_grr_main:
        :param SchRoute i_sch_branch_route:
        :param SchAppConnector i_sch_branch_route_cntr:
        :param SchAppConnection o_branch_cntn:
        :param SchAppConnector o_new_branch_cntr:
        :rtype: None
        """
        return self.sch_route.Branch(
            i_grr_main.com_object,
            i_sch_branch_route.com_object,
            i_sch_branch_route_cntr.com_object,
            o_branch_cntn.com_object,
            o_new_branch_cntr.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'branch'
        # # vba_code = """
        # # Public Function branch(sch_route)
        # #     Dim iGRRMain (2)
        # #     sch_route.Branch iGRRMain
        # #     branch = iGRRMain
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def break_(
            self,
            i_grr: SchGRRRoute,
            i_db2_pt1: tuple,
            i_db2_pt2: tuple,
            o_new_sch_route: 'SchRoute'
    ) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Break(SchGRRRoute iGRR,
                | CATSafeArrayVariant iDb2Pt1,
                | CATSafeArrayVariant iDb2Pt2,
                | SchRoute oNewSchRoute)
                | 
                |     Break a route into 2 pieces. The old route is shortened and a new route is
                |     created.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             graphical primitive of the route to be broken (if NULL, assume
                |             there is only one graphical primitive) 
                |         iDb2Pt1
                |             X-Y coordinates of point 1 to break the route at (this point is
                |             mandatory). 
                |         iDb2Pt2
                |             X-Y coordinates of point 2 to break the route at (this point is
                |             optional). If provided the points in between point 1 and this point will be
                |             eliminated. Point 1 is the last point of the shortened old route and point 2 is
                |             the first point of the new route. If this point is not provided (sends in a
                |             NULL). point 1 and point 2 are the same. 
                |         oNewSchRoute
                |             The new Schematic route object 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchRoute
                |          Dim objArg1 As SchGRRRoute
                |          Dim dbVar2(2) As CATSafeArrayVariant
                |          Dim dbVar3(2) As CATSafeArrayVariant
                |          Dim objArg4 As SchRoute
                |           ...
                |          objThisIntf.BreakobjArg1,dbVar2,dbVar3,objArg4

        :param SchGRRRoute i_grr:
        :param tuple i_db2_pt1:
        :param tuple i_db2_pt2:
        :param SchRoute o_new_sch_route:
        :rtype: tuple
        """
        return self.sch_route.Break(i_grr.com_object, i_db2_pt1, i_db2_pt2, o_new_sch_route.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'break'
        # # vba_code = """
        # # Public Function break(sch_route)
        # #     Dim iGRR (2)
        # #     sch_route.Break iGRR
        # #     break = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def compress(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Compress()
                | 
                |     Compress a the defining points of a route, removing coincident
                |     points.
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchRoute
                |           ...
                |          objThisIntf.Compress

        :rtype: None
        """
        return self.sch_route.Compress()

    def concatenate(
            self,
            i_sch_route1_cntr: SchAppConnector,
            i_sch_route2: 'SchRoute',
            i_sch_route2_cntr: SchAppConnector
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Concatenate(SchAppConnector iSchRoute1Cntr,
                | SchRoute iSchRoute2,
                | SchAppConnector iSchRoute2Cntr)
                | 
                |     Concatenate 2 routes into one. Only works for those that have only one line
                |     graphic object. The first route is elongated and is modified. The second route
                |     is deleted.
                | 
                |     Parameters:
                | 
                |         iSchRoute1Cntr
                |             Connector of this route to concatenate with the second route.
                |             
                |         iSchRoute2
                |             Second route to be concatenate to the first. iSchRoute2 will be
                |             deleted. 
                |         iSchRoute2Cntr
                |             Connector of second route to concatenate with the first route.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchRoute
                |          Dim objArg1 As SchAppConnector
                |          Dim objArg2 As SchRoute
                |          Dim objArg3 As SchAppConnector
                |           ...
                |          objThisIntf.ConcatenateobjArg1,objArg2,objArg3

        :param SchAppConnector i_sch_route1_cntr:
        :param SchRoute i_sch_route2:
        :param SchAppConnector i_sch_route2_cntr:
        :rtype: None
        """
        return self.sch_route.Concatenate(
            i_sch_route1_cntr.com_object,
            i_sch_route2.com_object,
            i_sch_route2_cntr.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'concatenate'
        # # vba_code = """
        # # Public Function concatenate(sch_route)
        # #     Dim iSchRoute1Cntr (2)
        # #     sch_route.Concatenate iSchRoute1Cntr
        # #     concatenate = iSchRoute1Cntr
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def concatenate_keep_route2(
            self,
            i_sch_route1_cntr: SchAppConnector,
            i_sch_route2: 'SchRoute',
            i_sch_route2_cntr: SchAppConnector
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ConcatenateKeepRoute2(SchAppConnector iSchRoute1Cntr,
                | SchRoute iSchRoute2,
                | SchAppConnector iSchRoute2Cntr)
                | 
                |     Concatenate 2 routes into one. Only works for those that have only one line
                |     graphic object. The first route is elongated and is modified. The second route
                |     is unchanged.
                | 
                |     Parameters:
                | 
                |         iSchRoute1Cntr
                |             Connector of this route to concatenate with the second route.
                |             
                |         iSchRoute2
                |             Second route to be concatenate to the first. iSchRoute2 will be
                |             unchanged. 
                |         iSchRoute2Cntr
                |             Connector of second route to concatenate with the first route.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchRoute
                |          Dim objArg1 As SchAppConnector
                |          Dim objArg2 As SchRoute
                |          Dim objArg3 As SchAppConnector
                |           ...
                |          objThisIntf.ConcatenateKeepRoute2objArg1,objArg2,objArg3

        :param SchAppConnector i_sch_route1_cntr:
        :param SchRoute i_sch_route2:
        :param SchAppConnector i_sch_route2_cntr:
        :rtype: None
        """
        return self.sch_route.ConcatenateKeepRoute2(
            i_sch_route1_cntr.com_object,
            i_sch_route2.com_object,
            i_sch_route2_cntr.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'concatenate_keep_route2'
        # # vba_code = """
        # # Public Function concatenate_keep_route2(sch_route)
        # #     Dim iSchRoute1Cntr (2)
        # #     sch_route.ConcatenateKeepRoute2 iSchRoute1Cntr
        # #     concatenate_keep_route2 = iSchRoute1Cntr
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_extremity_cntrs(
            self,
            i_grr: SchGRRRoute,
            o_route_cntr1: SchAppConnector,
            o_route_cntr2: SchAppConnector
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetExtremityCntrs(SchGRRRoute iGRR,
                | SchAppConnector oRouteCntr1,
                | SchAppConnector oRouteCntr2)
                | 
                |     Get extremity connectors of the route.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             graphical primitive of the route to query. (if NULL, assume there
                |             is only one graphical primitive) 
                |         oRouteCntr1
                |             Route connector at first extremity 
                |         oRouteCntr2
                |             Route connector at second extremity 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchRoute
                |          Dim objArg1 As SchGRRRoute
                |          Dim objArg2 As SchAppConnector
                |          Dim objArg3 As SchAppConnector
                |           ...
                |          objThisIntf.GetExtremityCntrsobjArg1,objArg2,objArg3

        :param SchGRRRoute i_grr:
        :param SchAppConnector o_route_cntr1:
        :param SchAppConnector o_route_cntr2:
        :rtype: None
        """
        return self.sch_route.GetExtremityCntrs(i_grr.com_object, o_route_cntr1.com_object, o_route_cntr2.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_extremity_cntrs'
        # # vba_code = """
        # # Public Function get_extremity_cntrs(sch_route)
        # #     Dim iGRR (2)
        # #     sch_route.GetExtremityCntrs iGRR
        # #     get_extremity_cntrs = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_path(self, i_grr: SchGRRRoute, o_l_db2_pt_path: SchListOfDoubles) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetPath(SchGRRRoute iGRR,
                | SchListOfDoubles oLDb2PtPath)
                | 
                |     Get the defining points of a route.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             graphical primitive of the route get the path from (if NULL, assume
                |             there is only one graphical primitive) 
                |         oLDbPtPath
                |             A list of X-Y coordinates of points. 2 doubles per point.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchRoute
                |          Dim objArg1 As SchGRRRoute
                |          Dim objArg2 As SchListOfDoubles
                |           ...
                |          objThisIntf.GetPathobjArg1,objArg2

        :param SchGRRRoute i_grr:
        :param SchListOfDoubles o_l_db2_pt_path:
        :rtype: None
        """
        return self.sch_route.GetPath(i_grr.com_object, o_l_db2_pt_path.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_path'
        # # vba_code = """
        # # Public Function get_path(sch_route)
        # #     Dim iGRR (2)
        # #     sch_route.GetPath iGRR
        # #     get_path = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def ok_to_branch(self, i_grr: SchGRRRoute, i_branch_class_type: str, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub OKToBranch(SchGRRRoute iGRR,
                | CATBSTR iBranchClassType,
                | boolean oBYes)
                | 
                |     Query whether it is OK to create a branch.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             graphical primitive of the route to query. (if NULL, assume there
                |             is only one graphical primitive) 
                |         iBranchClassType
                |             Class type of the branch to create. 
                |         oBYes
                |             If TRUE, then it is OK to create a branch from a route
                |
                |     Example:
                |
                |          Dim objThisIntf As SchRoute
                |          Dim objArg1 As SchGRRRoute
                |          Dim strVar2 As String
                |          Dim bVar3 As boolean
                |           ...
                |          objThisIntf.OKToBranchobjArg1,strVar2,bVar3

        :param SchGRRRoute i_grr:
        :param str i_branch_class_type:
        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_route.OKToBranch(i_grr.com_object, i_branch_class_type, o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'ok_to_branch'
        # # vba_code = """
        # # Public Function ok_to_branch(sch_route)
        # #     Dim iGRR (2)
        # #     sch_route.OKToBranch iGRR
        # #     ok_to_branch = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def ok_to_break(self, i_grr: SchGRRRoute, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub OKToBreak(SchGRRRoute iGRR,
                | boolean oBYes)
                | 
                |     Query whether it is OK to break.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             graphical primitive of the route to query. (if NULL, assume there
                |             is only one graphical primitive) 
                |         oBYes
                |             If TRUE, then it is OK to break the route 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchRoute
                |          Dim objArg1 As SchGRRRoute
                |          Dim bVar2 As boolean
                |           ...
                |          objThisIntf.OKToBreakobjArg1,bVar2

        :param SchGRRRoute i_grr:
        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_route.OKToBreak(i_grr.com_object, o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'ok_to_break'
        # # vba_code = """
        # # Public Function ok_to_break(sch_route)
        # #     Dim iGRR (2)
        # #     sch_route.OKToBreak iGRR
        # #     ok_to_break = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def ok_to_concatenate(self, i_grr: SchGRRRoute, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub OKToConcatenate(SchGRRRoute iGRR,
                | boolean oBYes)
                | 
                |     Query whether it is OK to concatenate.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             graphical primitive of the route to query. (if NULL, assume there
                |             is only one graphical primitive) 
                |         oBYes
                |             If TRUE, then it is OK to concatenate the route with another
                |
                |     Example:
                |
                |          Dim objThisIntf As SchRoute
                |          Dim objArg1 As SchGRRRoute
                |          Dim bVar2 As boolean
                |           ...
                |          objThisIntf.OKToConcatenateobjArg1,bVar2

        :param SchGRRRoute i_grr:
        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_route.OKToConcatenate(i_grr.com_object, o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'ok_to_concatenate'
        # # vba_code = """
        # # Public Function ok_to_concatenate(sch_route)
        # #     Dim iGRR (2)
        # #     sch_route.OKToConcatenate iGRR
        # #     ok_to_concatenate = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def ok_to_modify_points(self, i_grr: SchGRRRoute, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub OKToModifyPoints(SchGRRRoute iGRR,
                | boolean oBYes)
                | 
                |     Query whether it is OK to modify (add or remove) the
                |     points.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             graphical primitive of the route to query. (if NULL, assume there
                |             is only one graphical primitive). 
                |         oBYes
                |             If TRUE, then it is OK to add or remove the points from the route
                |
                |     Example:
                |
                |          Dim objThisIntf As SchRoute
                |          Dim objArg1 As SchGRRRoute
                |          Dim bVar2 As boolean
                |           ...
                |          objThisIntf.OKToModifyPointsobjArg1,bVar2

        :param SchGRRRoute i_grr:
        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_route.OKToModifyPoints(i_grr.com_object, o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'ok_to_modify_points'
        # # vba_code = """
        # # Public Function ok_to_modify_points(sch_route)
        # #     Dim iGRR (2)
        # #     sch_route.OKToModifyPoints iGRR
        # #     ok_to_modify_points = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_points(self, i_grr: SchGRRRoute, i_num_of_pts_to_remove: int, i_after_which_pt_num: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemovePoints(SchGRRRoute iGRR,
                | long iNumOfPtsToRemove,
                | long iAfterWhichPtNum)
                | 
                |     Remove points from route. Modify the route according to the route
                |     mode.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             graphical primitive of the route to remove the points from (if
                |             NULL, assume there is only one graphical primitive)
                |             
                |         iNumOfPtsToRemove
                |             The number of points to be removed 
                |         iAfterWhichPtNum
                |             The point number at which to start removing the point.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchRoute
                |          Dim objArg1 As SchGRRRoute
                |          Dim intVar2 As Integer
                |          Dim intVar3 As Integer
                |           ...
                |          objThisIntf.RemovePointsobjArg1,intVar2,intVar3

        :param SchGRRRoute i_grr:
        :param int i_num_of_pts_to_remove:
        :param int i_after_which_pt_num:
        :rtype: None
        """
        return self.sch_route.RemovePoints(i_grr.com_object, i_num_of_pts_to_remove, i_after_which_pt_num)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_points'
        # # vba_code = """
        # # Public Function remove_points(sch_route)
        # #     Dim iGRR (2)
        # #     sch_route.RemovePoints iGRR
        # #     remove_points = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def reshape_extremity(self, i_grr: SchGRRRoute, i_route_cntr: SchAppConnector, i_db2_delta_xy: tuple) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ReshapeExtremity(SchGRRRoute iGRR,
                | SchAppConnector iRouteCntr,
                | CATSafeArrayVariant iDb2DeltaXY)
                | 
                |     Change the position of the extremity of the route.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             graphical primitive of the route to reshape (if NULL, assume there
                |             is only one graphical primitive) 
                |         iRouteCntr
                |             Route connector whose position is to be modified
                |             (CATISchAppConnector interface pointer). 
                |         iDb2DeltaXY
                |             Delta X-Y coordinates of the extremity move 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchRoute
                |          Dim objArg1 As SchGRRRoute
                |          Dim objArg2 As SchAppConnector
                |          Dim dbVar3(2) As CATSafeArrayVariant
                |           ...
                |          objThisIntf.ReshapeExtremityobjArg1,objArg2,dbVar3

        :param SchGRRRoute i_grr:
        :param SchAppConnector i_route_cntr:
        :param tuple i_db2_delta_xy:
        :rtype: tuple
        """
        return self.sch_route.ReshapeExtremity(i_grr.com_object, i_route_cntr.com_object, i_db2_delta_xy)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'reshape_extremity'
        # # vba_code = """
        # # Public Function reshape_extremity(sch_route)
        # #     Dim iGRR (2)
        # #     sch_route.ReshapeExtremity iGRR
        # #     reshape_extremity = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def reshape_extremity2(
            self,
            i_e_route_mode: int,
            i_grr: SchGRRRoute,
            i_route_cntr: SchAppConnector,
            i_db2_pt_to_move_cntr_to: tuple
    ) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ReshapeExtremity2(CatSchIDLRouteMode iERouteMode,
                | SchGRRRoute iGRR,
                | SchAppConnector iRouteCntr,
                | CATSafeArrayVariant iDb2PtToMoveCntrTo)
                | 
                |     Change the position of the extremity of the route. Modify the route
                |     according to the route mode.
                | 
                |     Parameters:
                | 
                |         iERouteMode
                |             Routing mode. 
                |         iGRR
                |             graphical primitive of the route to reshape (if NULL, assume there
                |             is only one graphical primitive) 
                |         iRouteCntr
                |             Route connector whose position is to be modified (CATISchConnector
                |             interface pointer). 
                |         iDb2PtToMoveCntrTo
                |             X-Y coordinates of the point to move the connector to.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchRoute
                | 
                |          Dim objArg2 As SchGRRRoute
                |          Dim objArg3 As SchAppConnector
                |          Dim dbVar4(2) As CATSafeArrayVariant
                |           ...
                |          objThisIntf.ReshapeExtremity2CatSchIDLRouteMode_Enum,objArg2,objArg3,dbVar4

        :param int i_e_route_mode: enum cat_sch_idl_route_mode
        :param SchGRRRoute i_grr:
        :param SchAppConnector i_route_cntr:
        :param tuple i_db2_pt_to_move_cntr_to:
        :rtype: tuple
        """
        return self.sch_route.ReshapeExtremity2(
            i_e_route_mode,
            i_grr.com_object,
            i_route_cntr.com_object,
            i_db2_pt_to_move_cntr_to
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'reshape_extremity2'
        # # vba_code = """
        # # Public Function reshape_extremity2(sch_route)
        # #     Dim iERouteMode (2)
        # #     sch_route.ReshapeExtremity2 iERouteMode
        # #     reshape_extremity2 = iERouteMode
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_path(self, i_grr: SchGRRRoute, i_l_db2_pt_path: tuple) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPath(SchGRRRoute iGRR,
                | CATSafeArrayVariant iLDb2PtPath)
                | 
                |     Set the defining points of a route.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             graphical primitive of the route to set the path on (if NULL,
                |             assume there is only one graphical primitive) 
                |         iLDbPtPath
                |             A list of X-Y coordinates of points to be set. 2 doubles per point.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchRoute
                |          Dim objArg1 As SchGRRRoute
                |          Dim dbVar2(x) As CATSafeArrayVariant
                |           ...
                |          objThisIntf.SetPathobjArg1,dbVar2

        :param SchGRRRoute i_grr:
        :param tuple i_l_db2_pt_path:
        :rtype: tuple
        """
        return self.sch_route.SetPath(i_grr.com_object, i_l_db2_pt_path)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_path'
        # # vba_code = """
        # # Public Function set_path(sch_route)
        # #     Dim iGRR (2)
        # #     sch_route.SetPath iGRR
        # #     set_path = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchRoute(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_rsc_interfaces.rendering_light import RenderingLight
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class RenderingLights(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     RenderingLights
                | 
                | A collection of all the Rendering Lights objects.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=RenderingLight)
        self.rendering_lights = com_object

    def add(self) -> RenderingLight:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add() As RenderingLight
                | 
                |     Adds a new light to the lights collection.

        :rtype: RenderingLight
        """
        return RenderingLight(self.rendering_lights.Add())

    def item(self, i_index: cat_variant) -> RenderingLight:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As RenderingLight
                | 
                |     Returns a rendering light index in the rendering light
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the light to retrieve in the collection of lights.
                |             Compared with other collections, you cannot use the name of the light as
                |             argument. 
                | 
                |     Returns:
                |         The retrieved light 
                | 
                | Example:
                |     The following example returns in MyLight the sixth light in a lights
                |     collection.
                | 
                |      Dim MyLight As RenderingLight
                |      Set MyLight = RenderingLights.Item(6)

        :param cat_variant i_index:
        :rtype: RenderingLight
        """
        return RenderingLight(self.rendering_lights.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes a light from the lights collection.

        :param cat_variant i_index:
        :rtype: None
        """
        return self.rendering_lights.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(rendering_lights)
        # #     Dim iIndex (2)
        # #     rendering_lights.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_all(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveAll()
                | 
                |     Removes all lights from the collection.

        :rtype: None
        """
        return self.rendering_lights.RemoveAll()

    def __repr__(self):
        return f'RenderingLights(name="{self.name}")'
